// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.math.geometry.Pose2d;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.constants.OIConstants;
import frc.robot.subsystems.Drivetrain;

/*
 * The objective for this part of testing is to just make sure swerve is working in a perfect world scenario.
 * This is designed to be as close the REV template as possible, the only difference being the naming of certain 
 * Constants and the positioning of instance variables and there declarations. 
 * 
 * We should try to solve in this branch:
 * - Does Field Oriented Drive work in a perfect world scenario?
 * - Is our weird module spin behavior still present?
 *  - If it is, can we do something about it?
 * 
 * Any changes we make should be able to be carried forward to part 2
 */
public class RobotContainer {
    private Drivetrain drivetrain;

    private CommandXboxController driver;

    public RobotContainer() {
        drivetrain = new Drivetrain(new Pose2d());

        driver = new CommandXboxController(OIConstants.kPrimaryXboxUSB);

        configureBindings();
    }

    private void configureBindings() {
        drivetrain.setDefaultCommand(
            drivetrain.teleopCommand(
                driver::getLeftY, 
                driver::getLeftX, 
                () -> { return -driver.getRightX(); }, 
                OIConstants.kTeleopDriveDeadband
            )
        );

        driver.a().onTrue(drivetrain.zeroHeadingCommand());
        
  }

  public Command getAutonomousCommand() {
        return null;
  }
}
